def test_base_tools_exist(base_command):
    """No verification required for base command."""
    base_command.verify_tools()
